@@ -20,8 +20,7 @@ use core::{
 
 use anyhow::Result;
 
-use crate::fp::Fp;
-use crate::fp4::Fp4;
+use crate::{fp::Fp, fp4::Fp4};
 
 // We represent a SHA-256 digest as 8 32-bit words instead of the
 // traditional 32 8-bit bytes.
@@ -64,7 +63,7 @@ impl Digest {
 
     pub fn to_hex(&self) -> String {
         fn hex(digit: u8) -> char {
-	    char::from_digit(digit as u32, 16).unwrap()
+            char::from_digit(digit as u32, 16).unwrap()
         }
         self.0
             .iter()
@@ -113,11 +112,15 @@ pub trait Sha: Clone + Debug {
 
     // Generate SHAs for various data types.
     fn hash_bytes(&self, bytes: &[u8]) -> Self::DigestPtr;
+
     fn hash_words(&self, words: &[u32]) -> Self::DigestPtr {
         self.hash_bytes(bytemuck::cast_slice(words) as &[u8])
     }
+
     fn hash_pair(&self, a: &Digest, b: &Digest) -> Self::DigestPtr;
+
     fn hash_fps(&self, fps: &[Fp]) -> Self::DigestPtr;
+
     fn hash_fp4s(&self, fp4s: &[Fp4]) -> Self::DigestPtr;
 
     // Generate a new digest by mixing two digests together via XOR,
@@ -127,6 +130,7 @@ pub trait Sha: Clone + Debug {
 
 // Default implementation is CPU-based.
 pub use crate::sha_cpu::Impl as DefaultImplementation;
+
 pub fn default_implementation() -> &'static DefaultImplementation {
     static DEFAULT_IMPLEMENTATION: DefaultImplementation = DefaultImplementation {};
     &DEFAULT_IMPLEMENTATION
